@@ -608,7 +608,7 @@ class plxShow {
 	 * @scope	home,categorie,article,tags,archives
 	 * @author	Anthony GUÉRIN, Florent MONTHEL, Stephane F
 	 **/
-	public function artCat($separator=',') {
+	public function artCat($separator=', ') {
 
 		$cats = array();
 		# Initialisation de notre variable interne
@@ -1186,6 +1186,7 @@ class plxShow {
 					}
 					$menu = str_replace('#static_url', $this->plxMotor->urlRewrite('?blog'),$menu);
 					$menu = str_replace('#static_name',L_PAGEBLOG_TITLE,$menu);
+					$menu = str_replace('#static_class','',$menu);
 					array_splice($menus, (intval($menublog)-1), 0, array($menu));
 				}
 			}
@@ -1481,6 +1482,7 @@ class plxShow {
 
 		$datetime = date('YmdHi');
 		$array=array();
+		$alphasort=array();
 		# On verifie qu'il y a des tags
 		if($this->plxMotor->aTags) {
 			# On liste les tags sans créer de doublon
@@ -1495,6 +1497,8 @@ class plxShow {
 								}
 								else
 									$array['_'.$tag]['count']++;
+								if(!in_array($t, $alphasort)) 
+									$alphasort[] = $t; # pour le tri alpha
 							}
 						}
 					}
@@ -1505,7 +1509,7 @@ class plxShow {
 			# tri des tags
 			switch($order) {
 				case 'alpha':
-					array_multisort($array);
+					if($alphasort) array_multisort($alphasort, SORT_ASC, $array);
 					break;
 				case 'random':
 					$arr_elem = array();
