@@ -4,7 +4,7 @@
 
 	<div id="container">
 
-		<div class="full-width">
+		<div class="width-sidebar">
 
 			<article role="article">
 
@@ -24,6 +24,8 @@
 
 		</div>
 
+		<?php include(dirname(__FILE__).'/sidebar.php'); ?>
+
 	</div>
 
 </section>
